getsitemap
==========

.. image:: https://readthedocs.org/projects/getsitemap/badge/?version=latest
   :target: https://getsitemap.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://badge.fury.io/py/getsitemap.svg
    :target: https://python.org/pypi/getsitemap
    :alt: PyPI version

getsitemap is a Python library that retrieves all of the URLs that are
found in all of the sitemaps on a website.

This project may be useful if you are building a search crawler or
sitemap URL status code validators.

You can read the documentation for this project on `Read the Docs <https://getsitemap.readthedocs.io/en/latest/>`_.

Code Quality
-------------

This library uses `tox`, `pytest`, and `flake8` to assure code quality.

To run code quality checks, run the following command:

.. code-block:: bash

    tox

License
-------

This project is licensed under the `MIT License <LICENSE>`_.

Contributors
------------

-  capjamesg
